termsofservice

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 19, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client handles terms of service-related operations.

func NewClient

func NewClient(cfg *config.Config) *Client

NewClient creates a new terms of service client.

func (*Client) Initiate

func (c *Client) Initiate(ctx context.Context, params *InitiateParams) (*InitiateResponse, error)

Initiate initiates the terms of service flow and returns a URL.

type InitiateParams

type InitiateParams struct {
	IdempotencyKey string  `json:"idempotency_key"`
	ReceiverID     *string `json:"receiver_id"`
	RedirectURL    *string `json:"redirect_url"`
}

InitiateParams represents parameters for initiating terms of service.

type InitiateResponse

type InitiateResponse struct {
	URL string `json:"url"`
}

InitiateResponse represents the response from initiating terms of service.

Jump to